@@ -18,6 +18,7 @@ use Predis\Command\Argument\Search\SchemaFields\NumericField;
 use Predis\Command\Argument\Search\SchemaFields\TagField;
 use Predis\Command\Argument\Search\SchemaFields\TextField;
 use Predis\Command\Argument\Search\SchemaFields\VectorField;
+use Predis\Command\PrefixableCommand;
 use Predis\Command\Redis\PredisCommandTestCase;
 
 /**
@@ -62,6 +63,23 @@ class FTCREATE_Test extends PredisCommandTestCase
         $this->assertSame(1, $this->getCommand()->parseResponse(1));
     }
 
+    /**
+     * @group disconnected
+     */
+    public function testPrefixKeys(): void
+    {
+        /** @var PrefixableCommand $command */
+        $command = $this->getCommand();
+        $actualArguments = ['arg1'];
+        $prefix = 'prefix:';
+        $expectedArguments = ['prefix:arg1'];
+
+        $command->setRawArguments($actualArguments);
+        $command->prefixKeys($prefix);
+
+        $this->assertSame($expectedArguments, $command->getArguments());
+    }
+
     /**
      * @group connected
      * @group relay-resp3
@@ -257,4 +275,21 @@ class FTCREATE_Test extends PredisCommandTestCase
             ],
         ];
     }
+
+    /**
+     * @group connected
+     * @requiresRedisVersion >= 8.2.0
+     * @return void
+     */
+    public function testVectorCreateVANAMA(): void
+    {
+        $redis = $this->getClient();
+
+        $this->assertEquals('OK', $redis->ftcreate('test', [
+            new VectorField(
+                'svs-vanama', 'SVS-VAMANA',
+                ['TYPE', 'FLOAT32', 'DIM', 4, 'DISTANCE_METRIC', 'L2']
+            ),
+        ]));
+    }
 }
